@@ -12,9 +12,10 @@ sub opt_spec {
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
     $self->usage_error("Filename is required") unless $opt->{filename};
+    return 1;
 }
 
-sub run {
+sub execute {
     my ( $self, $opt, $arg ) = @_;
 
     my $doc_as_str = join( "", <STDIN> );
